@@ -17,6 +17,8 @@
 
 package org.apache.doris.flink.catalog.doris;
 
+import org.apache.flink.api.java.tuple.Tuple2;
+
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -32,9 +34,11 @@ public class TableSchema {
     private DataModel model = DataModel.DUPLICATE;
     private List<String> distributeKeys = new ArrayList<>();
     private Map<String, String> properties = new HashMap<>();
-
     private Integer tableBuckets;
 
+    // Currently only supports auto partition, eg: DATE_TRUNC(column,interval)
+    private Tuple2<String, String> partitionInfo;
+
     public String getDatabase() {
         return database;
     }
@@ -106,4 +110,39 @@ public class TableSchema {
     public Integer getTableBuckets() {
         return tableBuckets;
     }
+
+    public Tuple2<String, String> getPartitionInfo() {
+        return partitionInfo;
+    }
+
+    public void setPartitionInfo(Tuple2<String, String> partitionInfo) {
+        this.partitionInfo = partitionInfo;
+    }
+
+    @Override
+    public String toString() {
+        return "TableSchema{"
+                + "database='"
+                + database
+                + '\''
+                + ", table='"
+                + table
+                + '\''
+                + ", tableComment='"
+                + tableComment
+                + '\''
+                + ", fields="
+                + fields
+                + ", keys="
+                + String.join(",", keys)
+                + ", model="
+                + model.name()
+                + ", distributeKeys="
+                + String.join(",", distributeKeys)
+                + ", properties="
+                + properties
+                + ", tableBuckets="
+                + tableBuckets
+                + '}';
+    }
 }
