@@ -18,6 +18,7 @@
 package org.apache.doris.flink.rest;
 
 import org.apache.flink.annotation.VisibleForTesting;
+import org.apache.flink.util.Preconditions;
 
 import com.fasterxml.jackson.core.JsonParseException;
 import com.fasterxml.jackson.core.JsonProcessingException;
@@ -92,6 +93,7 @@ public class RestService implements Serializable {
     private static final String FE_LOGIN = "/rest/v1/login";
     private static final ObjectMapper objectMapper = new ObjectMapper();
     private static final String TABLE_SCHEMA_API = "http://%s/api/%s/%s/_schema";
+    private static final String CATALOG_TABLE_SCHEMA_API = "http://%s/api/%s/%s/%s/_schema";
     private static final String QUERY_PLAN_API = "http://%s/api/%s/%s/_query_plan";
 
     /**
@@ -209,9 +211,9 @@ public class RestService implements Serializable {
         HttpURLConnection connection = (HttpURLConnection) realUrl.openConnection();
         connection.setRequestProperty("Authorization", authHeader(dorisOptions));
 
-        connection.connect();
         connection.setConnectTimeout(request.getConfig().getConnectTimeout());
         connection.setReadTimeout(request.getConfig().getSocketTimeout());
+        connection.connect();
         return parseResponse(connection, logger);
     }
 
@@ -243,7 +245,7 @@ public class RestService implements Serializable {
      * @throws IllegalArgumentException table identifier is illegal
      */
     @VisibleForTesting
-    static String[] parseIdentifier(String tableIdentifier, Logger logger)
+    public static String[] parseIdentifier(String tableIdentifier, Logger logger)
             throws IllegalArgumentException {
         logger.trace("Parse identifier '{}'.", tableIdentifier);
         if (StringUtils.isEmpty(tableIdentifier)) {
@@ -251,7 +253,8 @@ public class RestService implements Serializable {
             throw new IllegalArgumentException("table.identifier", tableIdentifier);
         }
         String[] identifier = tableIdentifier.split("\\.");
-        if (identifier.length != 2) {
+        // db.table or catalog.db.table
+        if (identifier.length != 2 && identifier.length != 3) {
             logger.error(ILLEGAL_ARGUMENT_MESSAGE, "table.identifier", tableIdentifier);
             throw new IllegalArgumentException("table.identifier", tableIdentifier);
         }
@@ -394,12 +397,26 @@ public class RestService implements Serializable {
             throws DorisException {
         logger.trace("Finding schema.");
         String[] tableIdentifier = parseIdentifier(options.getTableIdentifier(), logger);
-        String tableSchemaUri =
-                String.format(
-                        TABLE_SCHEMA_API,
-                        randomEndpoint(options.getFenodes(), logger),
-                        tableIdentifier[0],
-                        tableIdentifier[1]);
+        String tableSchemaUri;
+        if (tableIdentifier.length == 2) {
+            tableSchemaUri =
+                    String.format(
+                            TABLE_SCHEMA_API,
+                            randomEndpoint(options.getFenodes(), logger),
+                            tableIdentifier[0],
+                            tableIdentifier[1]);
+        } else if (tableIdentifier.length == 3) {
+            tableSchemaUri =
+                    String.format(
+                            CATALOG_TABLE_SCHEMA_API,
+                            randomEndpoint(options.getFenodes(), logger),
+                            tableIdentifier[0],
+                            tableIdentifier[1],
+                            tableIdentifier[2]);
+        } else {
+            throw new IllegalArgumentException(
+                    "table identifier is illegal, should be db.table or catalog.db.table");
+        }
         HttpGet httpGet = new HttpGet(tableSchemaUri);
         String response = send(options, readOptions, httpGet, logger);
         logger.debug("Find schema response is '{}'.", response);
@@ -529,6 +546,8 @@ public class RestService implements Serializable {
             DorisOptions options, DorisReadOptions readOptions, Logger logger)
             throws DorisException {
         String[] tableIdentifiers = parseIdentifier(options.getTableIdentifier(), logger);
+        Preconditions.checkArgument(
+                tableIdentifiers.length == 2, "table identifier is illegal, should be db.table");
         String readFields =
                 StringUtils.isBlank(readOptions.getReadFields())
                         ? "*"
@@ -546,6 +565,7 @@ public class RestService implements Serializable {
         }
         logger.info("Query SQL Sending to Doris FE is: '{}'.", sql);
         String[] tableIdentifier = parseIdentifier(options.getTableIdentifier(), logger);
+
         String queryPlanUri =
                 String.format(
                         QUERY_PLAN_API,
@@ -595,12 +615,12 @@ public class RestService implements Serializable {
         }
 
         if (queryPlan == null) {
-            logger.error(SHOULD_NOT_HAPPEN_MESSAGE);
+            logger.error(SHOULD_NOT_HAPPEN_MESSAGE + " res: " + response);
             throw new ShouldNeverHappenException();
         }
 
         if (queryPlan.getStatus() != REST_RESPONSE_STATUS_OK) {
-            String errMsg = "Doris FE's response is not OK, status is " + queryPlan.getStatus();
+            String errMsg = "Doris FE's response is not OK, res: " + response;
             logger.error(errMsg);
             throw new DorisException(errMsg);
         }
